Attribute VB_Name = "mWinVersion"
Option Explicit

'==============================================================================
'This module was written by Fahad Khowaja (fahadkhowaja@hotmail.com). Visit the
'website at http://www28.brinkster.com/win98xpsdc for latest info.
'==============================================================================

'Win32 API constants for determining the versions of Windows stored
'in the dwPlatformId member of OSVERSIONINFO type.
'------------------------------------------------------------------
Private Const VER_PLATFORM_WIN32_WINDOWS As Integer = 1     'Windows 9x/ME
Private Const VER_PLATFORM_WIN32_NT As Integer = 2          'Windows NT

'Constants defined by me to check for detailed versions
'Constants to check values stored in dwMajorVersion member of OSVERSIONINFO
'--------------------------------------------------------------------------
Private Const VER_MAJOR_WIN32_WINDOWSNT35 As Integer = 3    'Windows NT 3.51
Private Const VER_MAJOR_WIN32_WINDOWSNT4 As Integer = 4     'Windows NT 4.0
Private Const VER_MAJOR_WIN32_WINDOWS2000XP As Integer = 5  'Windows 2000/XP

'Constants to check values stored in dwMinorVersion member of OSVERSIONINFO
'--------------------------------------------------------------------------
Private Const VER_MINOR_WIN32_WINDOWS95 As Integer = 0      'Windows 95
Private Const VER_MINOR_WIN32_WINDOWS98 As Integer = 10     'Windows 98
Private Const VER_MINOR_WIN32_WINDOWSME As Integer = 90     'Windows ME
Private Const VER_MINOR_WIN32_WINDOWS2000 As Integer = 0    'Windows 2000

'To remember what type of windows we're running on
'-------------------------------------------------
Public sWinType As String

'This type is required for the GetVersionEx() Win32 API function
'---------------------------------------------------------------
Private Type OSVERSIONINFO
    dwOSVersionInfoSize As Long
    dwMajorVersion As Long
    dwMinorVersion As Long
    dwBuildNumber As Long
    dwPlatformId As Long
    szCSDVersion As String * 128 ' Maintenance string for PSS usage
End Type

'Win32 API function to find the Windows version.
'-----------------------------------------------
'Note: I have listed most of the values returned by the GetVersionEx function above.
'The ones that I've left out are useful for checking things like Service Packs
'installed and 98 Second Edition. Check MSDN (http://msdn.microsoft.com) for them.
'-----------------------------------------------------------------------------------
Private Declare Function GetVersionEx Lib "kernel32.dll" Alias "GetVersionExA" (lpVersionInformation As OSVERSIONINFO) As Long

'====================================================================================
'This function is used to find the version of Windows running on the PC.
'It returns the name of the OS if successful or an empty string when there is an error.
'It also sets sWinType to "9x" or "NT" depending on type of OS running.
'Capable of detecting:
'   Windows 95/98/ME/2000/NT3.51/NT4.0/XP
'====================================================================================

Public Function GetOSVersion() As String

Dim WinVersion As OSVERSIONINFO

WinVersion.dwOSVersionInfoSize = Len(WinVersion)

If (GetVersionEx(WinVersion)) <> 0 Then
    Select Case WinVersion.dwPlatformId
        Case VER_PLATFORM_WIN32_WINDOWS
            sWinType = "9x"
            Select Case WinVersion.dwMinorVersion
                Case VER_MINOR_WIN32_WINDOWS95
                    GetOSVersion = "Windows 95"
                Case VER_MINOR_WIN32_WINDOWS98
                    GetOSVersion = "Windows 98"
                Case VER_MINOR_WIN32_WINDOWSME
                    GetOSVersion = "Windows ME"
            End Select
        Case VER_PLATFORM_WIN32_NT
            sWinType = "NT"
            Select Case WinVersion.dwMajorVersion
                Case VER_MAJOR_WIN32_WINDOWSNT35
                    GetOSVersion = "Windown NT 3.51"
                Case VER_MAJOR_WIN32_WINDOWSNT4
                    GetOSVersion = "Windows NT 4.0"
                Case VER_MAJOR_WIN32_WINDOWS2000XP
                    If (WinVersion.dwMinorVersion = VER_MINOR_WIN32_WINDOWS2000) Then
                        GetOSVersion = "Windows 2000"
                    Else
                        GetOSVersion = "Windows XP"
                    End If
            End Select
    End Select
Else
    GetOSVersion = ""
End If

End Function
    
